import React, { useEffect, useState  } from 'react'

import PollListItem from "./PollListItem"
import FullScreenDialog from "./FullScreenDialog"

import './PollList.css'

const PollContext = React.createContext({
    polls: [],
    fetchPolls: () => {},
})

export default function PollList() {
    const [polls, setPolls] = useState([])
    const [editPoll, setEditPoll] = useState(false)

    const fetchPolls = async () => {
        const response = await fetch('/api/polls')
        const polls = await response.json()
        setPolls(polls)
    }

    useEffect(() => {
        fetchPolls()
    }, [])

    return (
        <div className="poll-list">
            <PollContext.Provider value={{polls, fetchPolls}}>
                {polls.map((poll) => (
                    PollListItem(poll, setEditPoll)
                ))}
            </PollContext.Provider>
            {editPoll ? <FullScreenDialog editPoll={editPoll} setEditPoll={setEditPoll} /> : null}
        </div>
    )
}
